@@ -7,7 +7,7 @@ use warnings;
 use File::Spec;
 use File::Find;
 
-our $VERSION = '0.12';
+our $VERSION = '0.14';
 
 our $basedir = undef;
 our @results = ();
@@ -158,14 +158,14 @@ sub useall(*) {
 # you know, this would be a nice application for currying...
 sub _wanted {
     my $name = File::Spec->abs2rel($_, $basedir);
-    return unless $name && $name ne File::Spec->curdir();
+    return unless $name && $name ne File::Spec->curdir() && substr($name, 0, 1) ne '.';
 
     if (-d && $prune) {
         $File::Find::prune = 1;
         return;
     }
 
-    return unless /\.pm$/ && -r;
+    return unless /\.pm$/;
 
     $name =~ s|\.pm$||;
     $name = join('::', File::Spec->splitdir($name));
@@ -180,23 +180,28 @@ sub _find(*) {
     my ($category) = @_;
     return undef unless defined $category;
 
-    my $dir = File::Spec->catdir(split(/::/, $category));
+    my $dir = File::Spec->catdir(split(/::|'/, $category));
 
-    my @dirs;
-    if (@Module::Find::ModuleDirs) {
-        @dirs = map { File::Spec->catdir($_, $dir) }
-            @Module::Find::ModuleDirs;
-    } else {
-        @dirs = map { File::Spec->catdir($_, $dir) } @INC;
-    }
     @results = ();
 
-    foreach $basedir (@dirs) {
-        	next unless -d $basedir;
-    	
-        find({wanted   => \&_wanted,
-              no_chdir => 1,
-              follow   => $followMode}, $basedir);
+    foreach my $inc (@Module::Find::ModuleDirs ? @Module::Find::ModuleDirs : @INC) {
+        if (ref $inc) {
+            if (my @files = eval { $inc->files }) {
+                push @results,
+                    map { s/^\Q$category\E::// ? $_ : () }
+                    map { s{/}{::}g; s{\.pm$}{}; $_ }
+                    grep { /\.pm$/ }
+                    @files;
+            }
+        }
+        else {
+            our $basedir = File::Spec->catdir($inc, $dir);
+
+            next unless -d $basedir;
+            find({wanted   => \&_wanted,
+                  no_chdir => 1,
+                  follow   => $followMode}, $basedir);
+        }
     }
 
     # filter duplicate modules
@@ -206,7 +211,7 @@ sub _find(*) {
     @results = map "$category\::$_", @results;
 
     @results = map {
-         ($_ =~ m{^(\w+(?:::\w+)*)$})[0] || die "$_ does not look like a package name"
+         ($_ =~ m{^(\w+(?:(?:::|')\w+)*)$})[0] || die "$_ does not look like a package name"
     } @results;
 
     return @results;
@@ -303,6 +308,24 @@ Fixed RT#62923: setmoduledirs(undef) doesn't reset to searching @INC
 Added more explicit tests.
 Thanks to Colin Robertson for his input.
 
+=item 0.13, 2015-03-09
+
+This release contains two contributions from Moritz Lenz:
+- Link to Module::Pluggable and Class::Factory::Util in "SEE ALSO"
+- Align package name parsing with how perl does it (allowing single quotes as module separator)
+
+Added test for meta.yml
+
+=item 0.14, 2019-12-25
+
+A long overdue update. Thank you for the many contributions!
+
+- Fixed RT#99055: Removed file readability check (pull request contributed by Moritz Lenz)
+- Now supports @INC hooks (pull request contributed by Graham Knop)
+- Now filters out filenames starting with a dot (pull request contributed by Desmond Daignault)
+- Now uses strict (pull request contributed by Shlomi Fish)
+- Fixed RT#122016: test/ files show up in metacpan (bug report contributed by Karen Etheridge)
+
 =back
 
 =head1 DEVELOPMENT NOTES
@@ -311,7 +334,7 @@ Please report any bugs using the CPAN RT system. The development repository for
 
 =head1 SEE ALSO
 
-L<perl>
+L<perl>, L<Module::Pluggable>, L<Class::Factory::Util>
 
 =head1 AUTHOR
 
